@@ -53,6 +53,8 @@
 #'
 #' # load learner and set search space
 #' learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE))
+#'
+#' # runtime of the example is too long
 #' \donttest{
 #' # hyperparameter tuning on the pima indians diabetes data set
 #' instance = tune(
@@ -61,7 +63,7 @@
 #'   learner = learner,
 #'   resampling = rsmp("holdout"),
 #'   measure = msr("classif.ce"),
-#'   term_evals = 42
+#'   term_evals = 200
 #' )
 #'
 #' # best performing hyperparameter configuration
@@ -132,14 +134,14 @@ TunerBatchIrace = R6Class("TunerBatchIrace",
   )
 )
 
-target_runner_tuning = function(experiment, exec.target.runner, scenario, target.runner) {# nolint
+target_runner_tuning = function(experiment, exec_target_runner, scenario, target_runner) {# nolint
   tuning_instance = scenario$targetRunnerData$inst
 
   xdt = map_dtr(experiment, function(e) {
     configuration = as.data.table(e$configuration)
     # add configuration and instance id to archive
-    set(configuration, j = "configuration", value = e$id.configuration)
-    set(configuration, j = "instance", value = e$id.instance)
+    set(configuration, j = "configuration", value = e$id_configuration)
+    set(configuration, j = "instance", value = e$id_instance)
     configuration
   })
   # fix logicals
