@@ -231,22 +231,44 @@ test_that("store_tuning_instance, store_benchmark_result and store_models flags
 })
 
 test_that("predict_type works", {
-  te = trm("evals", n_evals = 4)
-  task = tsk("iris")
-  ps = TEST_MAKE_PS1(n_dim = 1)
-  ms = msr("classif.ce")
-  tuner = tnr("grid_search", resolution = 3)
+  task = tsk("pima")
 
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
-    tuner = tuner, ps)
+  # response predict type
+   at = auto_tuner(
+    tuner = tnr("random_search"),
+    learner = lrn("classif.rpart"),
+    resampling = rsmp("holdout"),
+    measure = msr("classif.ce"),
+    terminator = trm("evals", n_evals = 4))
+
+  expect_equal(at$predict_type, "response")
 
   at$train(task)
   expect_equal(at$predict_type, "response")
   expect_equal(at$model$learner$predict_type, "response")
 
+  # change predict type after training
   at$predict_type = "prob"
   expect_equal(at$predict_type, "prob")
   expect_equal(at$model$learner$predict_type, "prob")
+
+  # prob predict type
+  at = auto_tuner(
+    tuner = tnr("random_search"),
+    learner = lrn("classif.rpart", predict_type = "prob"),
+    resampling = rsmp("holdout"),
+    measure = msr("classif.ce"),
+    terminator = trm("evals", n_evals = 4))
+
+  expect_equal(at$predict_type, "prob")
+
+  at$train(task)
+
+  expect_equal(at$predict_type, "prob")
+  expect_equal(at$model$learner$predict_type, "prob")
+
+  pred = at$predict(task)
+  expect_numeric(pred$score(msr("classif.auc")))
 })
 
 test_that("search space from TuneToken works", {
@@ -619,7 +641,9 @@ test_that("AutoTuner works with async tuner", {
   skip_if_not_installed("rush")
   flush_redis()
 
-  rush::rush_plan(n_workers = 2)
+  mirai::daemons(2)
+  rush::rush_plan(n_workers = 2, worker_type = "remote")
+
   at = auto_tuner(
     tuner = tnr("async_random_search"),
     learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE)),
@@ -657,24 +681,6 @@ test_that("AutoTuner works with internal tuning and validation", {
   expect_true(is.null(at$model$learner$state$internal_valid_task_ids))
 })
 
-test_that("AutoTuner works when internal_search_space is passed separately", {
-  task = tsk("iris")
-  search_space = ps(x = p_dbl(0.2, 0.3))
-  internal_search_space = ps(iter = p_int(upper = 1000L, aggr = function(x) length(x)))
-  at = auto_tuner(
-    tuner = tnr("random_search", batch_size = 2),
-    learner = lrn("classif.debug", early_stopping = TRUE, validate = "test"),
-    resampling = rsmp("cv", folds = 3),
-    search_space = search_space,
-    internal_search_space = internal_search_space,
-    measure = msr("classif.ce"),
-    term_evals = 4
-  )
-  at$train(task)
-  expect_equal(at$model$learner$param_set$values$iter, 3)
-  expect_false(at$model$learner$param_set$values$early_stopping)
-})
-
 test_that("AutoTuner works when internal_search_space is part of primary search space", {
   task = tsk("iris")
   search_space = ps(
